%global _hardened_build 1
%global systemctl_bin /usr/bin/systemctl

%define _prefix /opt/symas
%define _varfix /var/symas
%define _libdir %{_prefix}/lib
%define _etcfix %{_prefix}/etc

Name:		symas-openldap
Version:	2.5.5
Release:	1%{?dist}
Summary:	Symas's openldap build

License:	BSD
URL:		https://www.openldap.org

BuildRequires:	symas-openssl-devel, symas-cyrus-sasl-devel
BuildRequires:	gcc, libtool-ltdl-devel, symas-heimdal-devel
BuildRequires:	symas-libevent-devel, symas-libargon2-devel
BuildRequires:	cracklib-devel, systemd-devel
Source0: ftp://ftp.OpenLDAP.org/pub/OpenLDAP/openldap-release/openldap-%{version}.tgz
Source1: slapd.service
Source2: all_threads_full_bt.gdb
Source3: core_grab.gdb
Source4: core_wait.gdb
Source5: default_attach.gdb
Source6: connexitor.ldif
Source7: connexitor.schema
Source8: edupermission.ldif
Source9: edupermission.schema
Source10: eduperson.ldif
Source11: eduperson.schema
Source12: krb5-kdc.ldif
Source13: krb5-kdc.schema
Source14: qmail.ldif
Source15: qmail.schema
Source16: rfc2307bis.ldif
Source17: rfc2307bis.schema
Source18: samba.ldif
Source19: samba.schema
Source20: samba3.ldif
Source21: samba3.schema

AutoReqProv: No

Patch0: Install-slapd-watcher.patch
Patch1: passwd.patch

%description
Symas's OpenLDAP 2.5 build

%package libs
Summary:	openldap Libaries
Requires:	symas-openssl-libs, symas-cyrus-sasl-libs
AutoReqProv:	no

%description libs
The symas-openldap-libs package contains the openldap libraries

%package devel
Summary:	openldap Development
Requires:	symas-openldap-libs = %{version}-%{release}
AutoReqProv:        no

%description devel
The symas-openldap-devel package contains the linking libraries and include files

%package servers
Summary:	openldap server binaries
Requires:	symas-openldap-libs = %{version}-%{release}, symas-libargon2-libs, symas-heimdal-libs, cracklib >= 2.9.6
Requires:	symas-libevent-libs
Requires:	libtool-ltdl
Provides:	openldap-servers
Conflicts:	openldap-servers
AutoReqProv:	no

%description servers
The symas-openldap-servers package contains slapd and its modules

%package clients
Summary:        openldap client binaries
Requires: symas-openldap-libs = %{version}-%{release}
AutoReqProv:        no

%description clients
The symas-openldap-clients package contains client tools such as ldapsearch

%package moddev
Summary: OpenLDAP module development pieces
Requires: symas-openldap-devel = %{version}-%{release}
AutoReqProv:	no

%description moddev
This package allows development of slapd overlays and modules using the
OpenlDAP libraries. It includes module specific headers and the libtool
utility required for compilation.

%prep
%setup -qn openldap-%{version}
%patch0 -p1
%patch1 -p1

%build
export LDFLAGS="%{__global_ldflags} -L%{_libdir} -Wl,-rpath,%{_libdir}"
export CFLAGS="%{optflags} -fPIC"
export CPPFLAGS=-I%{_prefix}/include
./configure --prefix=%{_prefix} \
    --with-cyrus-sasl \
    --with-tls=openssl \
    --libexecdir=%{_libdir} \
    --datadir=%{_varfix} \
    --sysconfdir=%{_etcfix} \
    --sharedstatedir=%{_etcfix} \
    --localstatedir=%{_varfix} \
    --enable-dynamic \
    --enable-slapd \
    --enable-modules \
    --enable-balancer=mod \
    --enable-backends=mod \
        --disable-sql \
        --disable-ndb \
        --disable-perl \
        --disable-wt \
    --enable-overlays=mod \
        --disable-seqmod \
    --enable-argon2 \
    --enable-debug \
    --enable-spasswd \
    --enable-crypt
make depend
make DEFINES="-DSLAP_SCHEMA_EXPOSE"
make -C contrib/slapd-modules/autogroup prefix=%{_prefix} libexecdir=%{_libdir}
make -C contrib/slapd-modules/datamorph prefix=%{_prefix} libexecdir=%{_libdir}
make -C contrib/slapd-modules/lastbind prefix=%{_prefix} libexecdir=%{_libdir}
make -C contrib/slapd-modules/noopsrch prefix=%{_prefix} libexecdir=%{_libdir}
make -C contrib/slapd-modules/passwd/pbkdf2 prefix=%{_prefix} libexecdir=%{_libdir}
make -C contrib/slapd-modules/passwd/sha2 prefix=%{_prefix} libexecdir=%{_libdir}
make -C contrib/slapd-modules/ppm prefix=%{_prefix} libexecdir=%{_libdir} etcdir=%{_etcfix} OPT=-fPIC
make -C contrib/slapd-modules/rbac prefix=%{_prefix} libexecdir=%{_libdir}
make -C contrib/slapd-modules/smbk5pwd prefix=%{_prefix} libexecdir=%{_libdir} \
 HEIMDAL_INC='-I%{_prefix}/include/heimdal' HEIMDAL_LIB='-L%{_libdir} -lkrb5 -lkadm5srv' \
 SSL_INC='-I/opt/symas/include' SSL_LIB='-L/opt/symas/lib -lcrypto'
make -C contrib/slapd-modules/variant prefix=%{_prefix} libexecdir=%{_libdir}
pushd libraries/liblmdb
export XCFLAGS="%{optflags}"
make prefix=%{_prefix}
popd

%install
make install DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/autogroup install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/datamorph install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/lastbind install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/noopsrch install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/passwd/pbkdf2 install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/passwd/sha2 install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/ppm install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS="" etcdir=%{_etcfix}
make -C contrib/slapd-modules/rbac install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/smbk5pwd install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/variant install prefix=%{_prefix} libexecdir=%{_libdir} DESTDIR=%{buildroot} STRIP_OPTS=""

pushd libraries/liblmdb
make install prefix=%{_prefix} DESTDIR=%{buildroot}
popd

pushd tests/progs
make install prefix=%{_prefix} DESTDIR=%{buildroot}
popd

rm -f %{buildroot}%{_prefix}/include/lmdb.h
rm -f %{buildroot}%{_libdir}/liblmdb.a
rm -f %{buildroot}%{_libdir}/liblmdb.so
rm -f %{buildroot}%{_libdir}/openldap/autogroup.a
rm -f %{buildroot}%{_libdir}/openldap/datamorph.a
rm -f %{buildroot}%{_libdir}/openldap/lastbind.a
rm -f %{buildroot}%{_libdir}/openldap/noopsrch.a
rm -f %{buildroot}%{_libdir}/openldap/ppm.a
rm -f %{buildroot}%{_libdir}/openldap/pw-pbkdf2.a
rm -f %{buildroot}%{_libdir}/openldap/pw-sha2.a
rm -f %{buildroot}%{_libdir}/openldap/rbac.a
rm -f %{buildroot}%{_libdir}/openldap/smbk5pwd.a
rm -f %{buildroot}%{_libdir}/openldap/variant.a
rm -f %{buildroot}%{_etcfix}/openldap/ppm.example
rm -f %{buildroot}%{_libdir}/*.la
mkdir -p %{buildroot}%{_varfix}/openldap-data
mkdir -p %{buildroot}%{_varfix}/run
chmod 0755 %{buildroot}%{_libdir}/lib*.so*
chmod 0644 %{buildroot}%{_libdir}/openldap/*.la
install -m 0700 -d %{buildroot}%{_varfix}/openldap-data
install -m 0755 -d %{buildroot}%{_varfix}/run

# install an init script for the servers
mkdir -p %{buildroot}%{_unitdir}
install -m 0644 %SOURCE1 %{buildroot}%{_unitdir}/slapd.service

mkdir -p %{buildroot}%{_prefix}/bin/moddev
cp libtool %{buildroot}%{_prefix}/bin/moddev/
mkdir -p %{buildroot}%{_prefix}/include/moddev/ac
cp include/lber_pvt.h %{buildroot}%{_prefix}/include/moddev/
cp include/ldap_cdefs.h %{buildroot}%{_prefix}/include/moddev/
cp include/ldap_features.h %{buildroot}%{_prefix}/include/moddev/
cp include/lutil.h %{buildroot}%{_prefix}/include/moddev/
cp include/portable.h %{buildroot}%{_prefix}/include/moddev/
cp include/ac/assert.h %{buildroot}%{_prefix}/include/moddev/ac/
cp include/ac/fdset.h %{buildroot}%{_prefix}/include/moddev/ac/
cp include/ac/localize.h %{buildroot}%{_prefix}/include/moddev/ac/
cp include/ac/socket.h %{buildroot}%{_prefix}/include/moddev/ac/
cp include/ac/string.h %{buildroot}%{_prefix}/include/moddev/ac/

mkdir -p %{buildroot}%{_libdir}/gdb
install -m 0644 %SOURCE2 %{buildroot}%{_libdir}/gdb/
install -m 0644 %SOURCE3 %{buildroot}%{_libdir}/gdb/
install -m 0644 %SOURCE4 %{buildroot}%{_libdir}/gdb/
install -m 0644 %SOURCE5 %{buildroot}%{_libdir}/gdb/

install -m 0644 %SOURCE6 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE7 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE8 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE9 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE10 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE11 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE12 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE13 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE14 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE15 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE16 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE17 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE18 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE19 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE20 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE21 %{buildroot}%{_etcfix}/openldap/schema/

%check
make test

%post servers
%systemd_post slapd.service

%preun servers
%systemd_preun slapd.service

%postun servers
%systemd_postun_with_restart slapd.service


%files libs
%defattr(-,root,root)
%{_etcfix}/openldap/ldap.conf.default
%{_libdir}/*.so.*
%{_prefix}/share/man/man5/ldap.conf.5
%{_prefix}/share/man/man5/ldif.5

%files devel
%defattr(-,root,root)
%{_prefix}/include/*.h
%{_libdir}/*.a
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_prefix}/share/man/man3

%files servers
%defattr(-,root,root)
%{_prefix}/bin/mdb_*
%{_prefix}/sbin
%{_etcfix}
%{_libdir}/slapd
%{_libdir}/openldap
%{_libdir}/gdb
%{_prefix}/share/man/man1/mdb_*
%{_prefix}/share/man/man5/slap*.5
%{_prefix}/share/man/man5/lload*.5
%{_prefix}/share/man/man8
%{_varfix}
%{_unitdir}/slapd.service
%exclude %{_etcfix}/openldap/ldap.conf
%exclude %{_etcfix}/openldap/ldap.conf.default
%exclude %{_etcfix}/openldap/slapd.conf
%exclude %{_etcfix}/openldap/slapd.ldif
%exclude %{_prefix}/share/man/man5/ldap.conf.5
%exclude %{_prefix}/share/man/man5/ldif.5

%files clients
%defattr(-,root,root)
%{_prefix}/bin
%{_prefix}/share/man/man1
%exclude %{_prefix}/bin/mdb_*
%exclude %{_prefix}/share/man/man1/mdb_*

%files moddev
%{_prefix}/include/moddev
%{_prefix}/bin/moddev/libtool

%changelog
* Tue Jun 08 2021 Symas Support <support@symas.com> - 2.5.5-1
- OpenLDAP 2.5.5 release
* Tue May 25 2021 Symas Support <support@symas.com> - 2.5.4-5
- Change paths to match odd Symas Gold locations
* Tue May 25 2021 Symas Support <support@symas.com> - 2.5.4-4
- ITS6467-4.patch
- ITS6467-5.patch
* Thu May 13 2021 Symas Support <support@symas.com> - 2.5.4-3
- ITS9534.patch
- ITS9551.patch
- ITS6467-2.patch
- ITS9552.patch
- ITS6467-3.patch
* Tue May 11 2021 Symas Support <support@symas.com> - 2.5.4-2
- ITS6457 patch
- ITS6207 patch
- ITS6467.patch
- ITS8721 patch
- ITS8747 patch
- ITS9502 patch
- ITS9529 patch
- ITS9530 patch
- ITS9531 patch
- ITS9537 patch
- ITS9541 patch
- ITS9542 patch
- ITS9544 patch
- ITS9546 patch
- ITS9548 patch
* Tue Apr 6 2021 Symas Support <support@symas.com> - 2.5.4-1
- initial packaging
